psychopy_ext.models.GaborJet.test — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.models.GaborJet.test

`GaborJet.` `test`(im, cell_type='complex', grid_size=0, sigma=6.283185307179586)

  Apply GaborJet to given images.

  Args: | im (numpy.array) input image; can be (128,128) or (256,256) px size
  Kwargs: | cell_type (str, default: ‘complex’) Choose between ‘complex’(40 output values) and ‘simple’ (80 values, NOT FULLY WORKING YET) grid_size (int, default: 0) How many positions within an image to take sigma (float, default: 2*np.pi) Control the size of gaussian envelope
  Returns: | (JetsMagnitude, JetsPhase, grid_position)